..
    This file is part of Invenio.
    Copyright (C) 2016-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.



API Docs
========

.. automodule:: invenio_previewer.ext
   :members:
   :undoc-members:


API
---

.. automodule:: invenio_previewer.api
   :members:
   :undoc-members:


Utils
-----

.. automodule:: invenio_previewer.utils
   :members:
   :undoc-members:


Views
-----

.. automodule:: invenio_previewer.views
   :members:
   :undoc-members:


Webpack
-------

.. automodule:: invenio_previewer.webpack
   :members:
   :undoc-members:


Previewers
----------

CSV (Papaparser)
~~~~~~~~~~~~~~~~

.. automodule:: invenio_previewer.extensions.csv_papaparsejs
   :members:
   :undoc-members:

Default
~~~~~~~

.. automodule:: invenio_previewer.extensions.default
   :members:
   :undoc-members:

JSON (prism.js)
~~~~~~~~~~~~~~~

.. automodule:: invenio_previewer.extensions.json_prismjs
   :members:
   :undoc-members:

Markdown
~~~~~~~~

.. automodule:: invenio_previewer.extensions.mistune
   :members:
   :undoc-members:

PDF (pdf.js)
~~~~~~~~~~~~

.. automodule:: invenio_previewer.extensions.pdfjs
   :members:
   :undoc-members:

Simple Images
~~~~~~~~~~~~~

.. automodule:: invenio_previewer.extensions.simple_image
   :members:
   :undoc-members:

XML (prism.js)
~~~~~~~~~~~~~~

.. automodule:: invenio_previewer.extensions.xml_prismjs
   :members:
   :undoc-members:

ZIP
~~~

.. automodule:: invenio_previewer.extensions.zip
   :members:
   :undoc-members:
